@@ -1,3 +1,4 @@
+import logging
 from typing import Iterable, List
 
 import dateutil.parser
@@ -5,6 +6,8 @@ import dateutil.parser
 from trainerdex.http import HTTPClient, Route
 from trainerdex.models import Trainer, User, Teams
 
+log = logging.getLogger("trainerdex.leaderboard")
+
 
 class LeaderboardInstance:
     
